==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>レイヤツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>表示レイヤツール</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;L 画層</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>上部または下部の余白</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>画層名は空です。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>画層は既に存在します。</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>画層データ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>画層名:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">ペン</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>色:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>ラインの太さ:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>ラインタイプ:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>レイヤツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>表示レイヤツール</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;L 画層</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>全てのレイヤーを表示</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>全てのレイヤーを非表示</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>全てのレイヤの解凍</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>全てのレイヤの凍結</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>全てのレイヤーをロック</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>全てのレイヤーをアンロック</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>上部または下部の余白</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translation>画層名は空です。</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translation>画層は既に存在します。</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>画層データ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>画層名:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">ペン</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>属性</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>色:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>ラインの太さ:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>ラインタイプ:</translation>
    </message>
</context>
</TS>
